@@ -203,12 +203,35 @@ class MainWidget(object):
             width=200,
             margin=(0, 20, 0, 0)
         )
+        self.download_new_version_button = pn.widgets.Button(
+            button_type="danger",
+            align='center',
+            height=31,
+            width=200,
+            margin=(20, 20, 0, 0)
+        )
 
     def create_layout(self):
+
+        latest_github_version = alphaviz.utils.check_github_version(silent=False)
+
+        if latest_github_version and latest_github_version != alphaviz.__version__:
+            self.download_new_version_button.name = f"Download version {latest_github_version}"
+            download_new_version_button = self.download_new_version_button
+            download_new_version_button.js_on_click(
+                code=f"""window.open("https://github.com/MannLabs/alphaviz/releases/latest")"""
+            )
+        else:
+            download_new_version_button = None
+
         self.layout = pn.Row(
             self.project_description,
             pn.layout.HSpacer(width=500),
-            self.manual,
+            pn.Column(
+                self.manual,
+                download_new_version_button,
+                align='center',
+            ),
             background='#eaeaea',
             align='center',
             sizing_mode='stretch_width',
@@ -341,28 +364,34 @@ class DataImportWidget(BaseWidget):
         return self.layout
 
     def update_file_names(self, *args):
-        self.ms_file_name.options = alphaviz.preprocessing.sort_naturally(
-            alphaviz.io.get_filenames_from_directory(
-                self.path_raw_folder.value,
-                ['d', 'hdf']
+        try:
+            self.ms_file_name.options = alphaviz.preprocessing.sort_naturally(
+                alphaviz.io.get_filenames_from_directory(
+                    self.path_raw_folder.value,
+                    ['d', 'hdf']
+                )
             )
-        )
+        except OSError:
+            self.import_error.object = f"#### The selected directory is not found."
 
     def update_output_folder_and_fasta(self, *args):
-        data_folder = os.path.join(
-            self.path_raw_folder.value,
-            self.ms_file_name.value
-        )
-        for dirpath, dirnames, filenames in os.walk(data_folder):
-            for filename in filenames:
-                if filename.endswith(".fasta"):
-                    self.path_fasta_file.value = os.path.join(dirpath, filename)
-                elif filename == 'evidence.txt':
-                    self.path_output_folder.value = dirpath
-        if not self.path_fasta_file.value:
-            for filename in os.listdir(self.path_raw_folder.value):
-                if filename.endswith(".fasta"):
-                    self.path_fasta_file.value = os.path.join(self.path_raw_folder.value, filename)
+        try:
+            data_folder = os.path.join(
+                self.path_raw_folder.value,
+                self.ms_file_name.value
+            )
+            for dirpath, dirnames, filenames in os.walk(data_folder):
+                for filename in filenames:
+                    if filename.endswith(".fasta"):
+                        self.path_fasta_file.value = os.path.join(dirpath, filename)
+                    elif filename == 'evidence.txt':
+                        self.path_output_folder.value = dirpath
+            if not self.path_fasta_file.value:
+                for filename in os.listdir(self.path_raw_folder.value):
+                    if filename.endswith(".fasta"):
+                        self.path_fasta_file.value = os.path.join(self.path_raw_folder.value, filename)
+        except:
+            self.import_error.object = "#### The selected folder does not contain any .d or .hdf files."
 
     def load_data(self, *args):
         alphatims.utils.set_progress_callback(self.upload_progress)
@@ -491,7 +520,7 @@ class HeatmapOptionsWidget(object):
         )
         self.precursor_target_size = pn.widgets.IntInput(
             name='Precursor target size',
-            value=15,
+            value=20,
             step=5,
             start=0,
             end=100,
@@ -500,7 +529,7 @@ class HeatmapOptionsWidget(object):
         )
         self.precursor_target_color = pn.widgets.Select(
             name='Precursor target color',
-            value='blue',
+            value='lime',
             options=list(matplotlib.colors.CSS4_COLORS.keys()),
             width=180,
             margin=(20, 20, 20, 10),
@@ -595,7 +624,7 @@ class ColorscaleOptionsWidget(object):
                 self.colorscale_qualitative,
                 self.colorscale_sequential,
             ),
-            title='Color scheme options',
+            title='Customization options',
             collapsed=False,
             sizing_mode='stretch_width',
             margin=(15, 8, 15, 8),
@@ -659,15 +688,15 @@ class MainTab(object):
             verbose=False,
         )
         self.analysis_software = ""
-        self.heatmap_x_axis = options.layout[0][0][0]
-        self.heatmap_y_axis = options.layout[0][0][1]
-        self.heatmap_colormap = options.layout[0][0][2]
-        self.heatmap_background_color = options.layout[0][0][3]
-        self.heatmap_precursor_size = options.layout[0][0][4]
-        self.heatmap_precursor_color = options.layout[0][0][5]
-        self.mz_tol = options.layout[1][0][0]
-        self.im_tol = options.layout[1][0][1]
-        self.rt_tol = options.layout[1][0][2]
+        self.mz_tol = options.layout[0][0][0]
+        self.im_tol = options.layout[0][0][1]
+        self.rt_tol = options.layout[0][0][2]
+        self.heatmap_x_axis = options.layout[1][0][0]
+        self.heatmap_y_axis = options.layout[1][0][1]
+        self.heatmap_colormap = options.layout[1][0][2]
+        self.heatmap_background_color = options.layout[1][0][3]
+        self.heatmap_precursor_size = options.layout[1][0][4]
+        self.heatmap_precursor_color = options.layout[1][0][5]
         self.colorscale_qualitative = options.layout[2][0][0]
         self.colorscale_sequential = options.layout[2][0][1]
         self.protein_seq = str()
@@ -795,8 +824,8 @@ class MainTab(object):
                 self.rt_tol: [self.display_line_spectra_plots, 'value'],
                 self.x_axis_label_mq: [self.display_line_spectra_plots, 'value'],
                 self.x_axis_label_diann: [self.display_elution_profile_plots, 'value'],
-                self.colorscale_qualitative: [self.run_after_protein_selection, 'value'],
-                self.colorscale_sequential: [self.run_after_protein_selection, 'value'],
+                self.colorscale_qualitative: [self.run_after_peptide_selection, 'value'],
+                self.colorscale_sequential: [self.run_after_peptide_selection, 'value'],
             }
             for k in dependances.keys():
                 k.param.watch(
@@ -812,8 +841,10 @@ class MainTab(object):
             self.proteins_table.formatters = self.dictionary[self.analysis_software]['proteins_table']['formatters']
             self.proteins_table.widths = self.dictionary[self.analysis_software]['proteins_table']['widths']
             self.peptides_table.value = self.data.mq_evidence.iloc[0:0]
-            self.peptides_table.formatters = self.dictionary[self.analysis_software]['peptides_table']['formatters']
             self.peptides_table.widths = self.dictionary[self.analysis_software]['peptides_table']['widths']
+            if '(EXP) Seq coverage, %' in self.data.mq_protein_groups.columns:
+                self.proteins_table.formatters['(EXP) Seq coverage, %'] = {"type": "progress", "max": 100, "legend": True}
+
         elif self.analysis_software == 'diann':
             self.proteins_table.value = self.data.diann_proteins
             self.peptides_table.value = self.data.diann_peptides.iloc[0:0]
@@ -960,16 +991,13 @@ class MainTab(object):
             self.peptides_table.selection = []
             if self.analysis_software == 'maxquant':
                 self.gene_name = self.proteins_table.value.iloc[self.proteins_table.selection[0]]['Gene names']
-                curr_protein_ids = self.proteins_table.value.iloc[self.proteins_table.selection[0]]['Protein IDs']
-                self.peptides_table.value = alphaviz.preprocessing.filter_df(
-                    self.data.mq_evidence,
-                    pattern=self.gene_name.replace(';', '|'), # use the regex | character to try to match each of the substrings in the genes separated by ; in the "Gene names" column
-                    column='Gene names',
-                    software='maxquant',
-                )
+                self.peptides_table.value = self.data.mq_evidence[self.data.mq_evidence['Gene names'] == self.gene_name]
+                if self.peptides_table.value.empty:
+                    self.peptides_table.value = self.data.mq_evidence[self.data.mq_evidence['Gene names'].str.contains(self.gene_name)]
+                self.curr_protein_ids = [val.replace('CON__', '') if "|" not in val else val.split('|')[1].replace('CON__', '') for val in self.peptides_table.value['Leading razor protein'].sort_values(ascending=False).values][0]
             elif self.analysis_software == 'diann':
                 self.gene_name = self.proteins_table.value.iloc[self.proteins_table.selection[0]]['Gene names']
-                curr_protein_ids = self.proteins_table.value.iloc[self.proteins_table.selection[0]]['Protein IDs']
+                self.curr_protein_ids = self.proteins_table.value.iloc[self.proteins_table.selection[0]]['Protein IDs']
                 self.peptides_table.value = alphaviz.preprocessing.filter_df(
                     self.data.diann_peptides,
                     pattern=self.gene_name,
@@ -993,7 +1021,7 @@ class MainTab(object):
                 None, #Summed MS2 spectrum
             ]
             self.protein_seq = alphaviz.preprocessing.get_aa_seq(
-                curr_protein_ids,
+                self.curr_protein_ids,
                 self.data.fasta,
             )
             self.protein_coverage_plot = alphaviz.plotting.plot_sequence_coverage(
@@ -1002,8 +1030,31 @@ class MainTab(object):
                 self.peptides_table.value['Modified.Sequence'].tolist() if self.analysis_software == 'diann' else self.peptides_table.value['Modified sequence'].tolist(),
                 self.colorscale_qualitative.value,
                 self.colorscale_sequential.value,
-                r"\[([^]]+)\]|\((\w+)\)"
+                r"\[(.*?)\]|\((.*?)\)\)?",
+                self.curr_protein_ids
             )
+            if not self.protein_coverage_plot and self.analysis_software == 'maxquant':
+                curr_protein_ids = sorted(self.peptides_table.value['Proteins'].values[0].split(';'), reverse=True)
+                for prot_id in curr_protein_ids:
+                    if '|' in prot_id:
+                        prot_id = prot_id.split('|')[1]
+                    self.protein_seq = alphaviz.preprocessing.get_aa_seq(
+                        prot_id,
+                        self.data.fasta,
+                    )
+                    self.protein_coverage_plot = alphaviz.plotting.plot_sequence_coverage(
+                        self.protein_seq,
+                        self.gene_name,
+                        self.peptides_table.value['Modified.Sequence'].tolist() if self.analysis_software == 'diann' else self.peptides_table.value['Modified sequence'].tolist(),
+                        self.colorscale_qualitative.value,
+                        self.colorscale_sequential.value,
+                        r"\[(.*?)\]|\((.*?)\)\)?",
+                        prot_id
+                    )
+                    if self.protein_coverage_plot:
+                        self.curr_protein_ids = prot_id
+                        break
+
             self.layout[6] = pn.Pane(
                 self.protein_coverage_plot,
                 config=update_config(f"{self.gene_name}_coverage_plot"),
@@ -1044,7 +1095,8 @@ class MainTab(object):
                     [self.peptides_table.value.iloc[self.peptides_table.selection[0]]['Modified.Sequence']] if self.analysis_software == 'diann' else [self.peptides_table.value.iloc[self.peptides_table.selection[0]]['Modified sequence']],
                     self.colorscale_qualitative.value,
                     self.colorscale_sequential.value,
-                    r"\[([^]]+)\]|\((\w+)\)"
+                    r"\[(.*?)\]|\((.*?)\)\)?",
+                    self.curr_protein_ids
                 )
                 self.layout[6] = pn.Pane(
                     self.protein_coverage_plot,
@@ -1190,12 +1242,12 @@ class MainTab(object):
                             mz_tol=self.mz_tol.value,
                             rt_tol=self.rt_tol.value,
                             im_tol=self.im_tol.value,
-                            title=f"Precursor/fragments elution profile of {self.peptides_table.value.iloc[self.peptides_table.selection[0]]['Modified.Sequence']} in RT dimension ({self.peptide['rt'] / 60: .2f} min)",
+                            title=f"Precursor and fragment elution profiles of {self.peptides_table.value.iloc[self.peptides_table.selection[0]]['Modified.Sequence']} in RT dimension ({self.peptide['rt'] / 60:.2f} min)",
                             colorscale_qualitative=self.colorscale_qualitative.value,
                             colorscale_sequential=self.colorscale_sequential.value,
                         ),
                         sizing_mode='stretch_width',
-                        config=update_config('Precursor/fragments elution profile plot'),
+                        config=update_config('Precursor&fragment elution profile plot in RT dimension'),
                         loading=False,
                     ),
                     margin=(5, 10, 0, 10)
@@ -1219,7 +1271,6 @@ class MainTab(object):
                         ),
                         sizing_mode='stretch_width',
                         linked_axes=True,
-                        config=update_config('Precursor/fragments elution profile plot'),
                         loading=False,
                     ),
                     sizing_mode='stretch_width',
@@ -1239,48 +1290,51 @@ class MainTab(object):
                 mz = self.peptide['mz']
                 im = self.peptide['im']
             data_ms1 = self.data.raw_data[ms1_frame].copy()
-            self.heatmap_ms1_plot = alphaviz.plotting.plot_heatmap(
-                data_ms1,
-                mz=mz,
-                im=im,
-                x_axis_label=self.heatmap_x_axis.value,
-                y_axis_label=self.heatmap_y_axis.value,
-                title=f'MS1 frame(s) #{ms1_frame}',
-                colormap=self.heatmap_colormap.value,
-                background_color=self.heatmap_background_color.value,
-                precursor_size=self.heatmap_precursor_size.value,
-                precursor_color=self.heatmap_precursor_color.value,
-                width=570,
-                height=450,
-                margin=(0, 10, 10, 0),
-                # shared_axes=True
-            )
-            data_ms2 = self.data.raw_data[ms2_frame].copy()
-            self.heatmap_ms2_plot = alphaviz.plotting.plot_heatmap(
-                data_ms2,
-                x_axis_label=self.heatmap_x_axis.value,
-                y_axis_label=self.heatmap_y_axis.value,
-                title=f'MS2 frame(s) #{ms2_frame}',
-                colormap=self.heatmap_colormap.value,
-                background_color=self.heatmap_background_color.value,
-                width=570,
-                height=450,
-                margin=(0, 10, 10, 0),
-                # shared_axes=True
-            )
+            try:
+                self.heatmap_ms1_plot = alphaviz.plotting.plot_heatmap(
+                    data_ms1,
+                    mz=mz,
+                    im=im,
+                    x_axis_label=self.heatmap_x_axis.value,
+                    y_axis_label=self.heatmap_y_axis.value,
+                    title=f'MS1 frame(s) #{ms1_frame}',
+                    colormap=self.heatmap_colormap.value,
+                    background_color=self.heatmap_background_color.value,
+                    precursor_size=self.heatmap_precursor_size.value,
+                    precursor_color=self.heatmap_precursor_color.value,
+                    width=570,
+                    height=450,
+                    margin=(0, 10, 10, 0),
+                    # shared_axes=True
+                )
+                data_ms2 = self.data.raw_data[ms2_frame].copy()
+                self.heatmap_ms2_plot = alphaviz.plotting.plot_heatmap(
+                    data_ms2,
+                    x_axis_label=self.heatmap_x_axis.value,
+                    y_axis_label=self.heatmap_y_axis.value,
+                    title=f'MS2 frame(s) #{ms2_frame}',
+                    colormap=self.heatmap_colormap.value,
+                    background_color=self.heatmap_background_color.value,
+                    width=570,
+                    height=450,
+                    margin=(0, 10, 10, 0),
+                    # shared_axes=True
+                )
 
-            self.layout[10][0] = pn.pane.HoloViews(
-                self.heatmap_ms1_plot,
-                margin=(15, 0, 0, 0),
-                linked_axes=False,
-                loading=False
-            )
-            self.layout[10][1] = pn.pane.HoloViews(
-                self.heatmap_ms2_plot,
-                margin=(15, 0, 0, 0),
-                linked_axes=False,
-                loading=False
-            )
+                self.layout[10][0] = pn.pane.HoloViews(
+                    self.heatmap_ms1_plot,
+                    margin=(15, 0, 0, 0),
+                    linked_axes=False,
+                    loading=False
+                )
+                self.layout[10][1] = pn.pane.HoloViews(
+                    self.heatmap_ms2_plot,
+                    margin=(15, 0, 0, 0),
+                    linked_axes=False,
+                    loading=False
+                )
+            except ValueError:
+                print('The x- and y-axis of the heatmaps should be different.')
             if self.analysis_software == 'diann':
                 if self.x_axis_label_diann.value == 'RT/IM dimension':
                     self.display_elution_profile_plots()
@@ -1304,7 +1358,8 @@ class MainTab(object):
                     config=update_config('Combined MS2 spectrum'),
                     margin=(10, 0, 0, 0),
                     sizing_mode='stretch_width',
-                    loading=False
+                    loading=False,
+                    height=600
                 )
 
     def display_previous_frame(self, *args):
@@ -1347,42 +1402,45 @@ class MainTab(object):
         if self.plot_overlapped_frames.value == True:
             mz = float(self.peptides_table.value.iloc[self.peptides_table.selection[0]]['m/z'])
             im = float(self.peptides_table.value.iloc[self.peptides_table.selection[0]]['1/K0'])
-            self.heatmap_ms1_plot = alphaviz.plotting.plot_heatmap(
-                self.data.raw_data[list(self.ms1_ms2_frames.keys())],
-                mz=mz,
-                im=im,
-                x_axis_label=self.heatmap_x_axis.value,
-                y_axis_label=self.heatmap_y_axis.value,
-                title=f'MS1 frame(s) #{list(self.ms1_ms2_frames.keys())}',
-                colormap=self.heatmap_colormap.value,
-                background_color=self.heatmap_background_color.value,
-                width=570,
-                height=450,
-                margin=(0, 10, 10, 0),
-            )
-            self.heatmap_ms2_plot = alphaviz.plotting.plot_heatmap(
-                self.data.raw_data[[val[0] for val in self.ms1_ms2_frames.values()]],
-                x_axis_label=self.heatmap_x_axis.value,
-                y_axis_label=self.heatmap_y_axis.value,
-                title=f'MS2 frame(s) #{[val[0] for val in self.ms1_ms2_frames.values()]}',
-                colormap=self.heatmap_colormap.value,
-                background_color=self.heatmap_background_color.value,
-                width=570,
-                height=450,
-                margin=(0, 10, 10, 0),
-            )
-            self.layout[10][0] = pn.pane.HoloViews(
-                self.heatmap_ms1_plot,
-                margin=(15, 0, 0, 0),
-                linked_axes=False,
-                loading=False
-            )
-            self.layout[10][1] = pn.pane.HoloViews(
-                self.heatmap_ms2_plot,
-                margin=(15, 0, 0, 0),
-                linked_axes=False,
-                loading=False
-            )
+            try:
+                self.heatmap_ms1_plot = alphaviz.plotting.plot_heatmap(
+                    self.data.raw_data[list(self.ms1_ms2_frames.keys())],
+                    mz=mz,
+                    im=im,
+                    x_axis_label=self.heatmap_x_axis.value,
+                    y_axis_label=self.heatmap_y_axis.value,
+                    title=f'MS1 frame(s) #{list(self.ms1_ms2_frames.keys())}',
+                    colormap=self.heatmap_colormap.value,
+                    background_color=self.heatmap_background_color.value,
+                    width=570,
+                    height=450,
+                    margin=(0, 10, 10, 0),
+                )
+                self.heatmap_ms2_plot = alphaviz.plotting.plot_heatmap(
+                    self.data.raw_data[[val[0] for val in self.ms1_ms2_frames.values()]],
+                    x_axis_label=self.heatmap_x_axis.value,
+                    y_axis_label=self.heatmap_y_axis.value,
+                    title=f'MS2 frame(s) #{[val[0] for val in self.ms1_ms2_frames.values()]}',
+                    colormap=self.heatmap_colormap.value,
+                    background_color=self.heatmap_background_color.value,
+                    width=570,
+                    height=450,
+                    margin=(0, 10, 10, 0),
+                )
+                self.layout[10][0] = pn.pane.HoloViews(
+                    self.heatmap_ms1_plot,
+                    margin=(15, 0, 0, 0),
+                    linked_axes=False,
+                    loading=False
+                )
+                self.layout[10][1] = pn.pane.HoloViews(
+                    self.heatmap_ms2_plot,
+                    margin=(15, 0, 0, 0),
+                    linked_axes=False,
+                    loading=False
+                )
+            except ValueError:
+                print('The x- and y-axis of the heatmaps should be different.')
             self.layout[12] = None
         else:
             self.display_heatmap_spectrum()
@@ -1392,23 +1450,34 @@ class QCTab(object):
     def __init__(self, data, options):
         self.name = "Quality Control"
         self.data = data
+        self.mz_tol = options.layout[0][0][0]
         self.layout_qc = None
         self.analysis_software = self.data.settings.get('analysis_software')
 
     def create_layout(self):
+        dependances = {
+            self.mz_tol: [self.update_tol_range_mass_density, 'value'],
+        }
+        for k in dependances.keys():
+            k.param.watch(
+                dependances[k][0],
+                dependances[k][1]
+            )
+
         experiment = self.data.ms_file_name.value.split('.')[0]
         if self.analysis_software == 'maxquant':
             uncalb_mass_dens_plot = alphaviz.plotting.plot_mass_error(
                 self.data.mq_evidence,
                 'm/z',
                 'Uncalibrated mass error [ppm]',
-                'Uncalibrated mass density plot'
+                'Uncalibrated mass density plot',
+                self.mz_tol.value,
             )
             calb_mass_dens_plot = alphaviz.plotting.plot_mass_error(
                 self.data.mq_evidence,
                 'm/z',
                 'Mass error [ppm]',
-                'Calibrated mass density plot'
+                'Calibrated mass density plot',
             )
             peptide_per_protein_distr = alphaviz.plotting.plot_pept_per_protein_barplot(
                 self.data.mq_protein_groups,
@@ -1418,12 +1487,12 @@ class QCTab(object):
             peptide_mz_distr = alphaviz.plotting.plot_peptide_distr(
                 self.data.mq_evidence,
                 'm/z',
-                'Peptide m/z distribution'
+                'Peptide m/z distribution',
             )
             peptide_length_distr = alphaviz.plotting.plot_peptide_distr(
                 self.data.mq_evidence,
                 'Length',
-                'Peptide length distribution'
+                'Peptide length distribution',
             )
 
             self.layout_qc = pn.Column(
@@ -1513,21 +1582,33 @@ class QCTab(object):
             )
         return self.layout_qc
 
+    def update_tol_range_mass_density(self, *args):
+        if self.analysis_software == 'maxquant' and self.layout_qc:
+            self.layout_qc[2][0] = pn.Pane(
+                alphaviz.plotting.plot_mass_error(
+                    self.data.mq_evidence,
+                    'm/z',
+                    'Uncalibrated mass error [ppm]',
+                    'Uncalibrated mass density plot',
+                    self.mz_tol.value,
+                ),
+                config=update_config('Uncalibrated mass density plot'),
+            )
+
 
 class TargetModeTab(object):
-
     def __init__(self, data, options):
         self.name = "Targeted Mode"
         self.data = data
-        self.heatmap_x_axis = options.layout[0][0][0]
-        self.heatmap_y_axis = options.layout[0][0][1]
-        self.heatmap_colormap = options.layout[0][0][2]
-        self.heatmap_background_color = options.layout[0][0][3]
-        self.heatmap_precursor_size = options.layout[0][0][4]
-        self.heatmap_precursor_color = options.layout[0][0][5]
-        self.mz_tol = options.layout[1][0][0]
-        self.im_tol = options.layout[1][0][1]
-        self.rt_tol = options.layout[1][0][2]
+        self.mz_tol = options.layout[0][0][0]
+        self.im_tol = options.layout[0][0][1]
+        self.rt_tol = options.layout[0][0][2]
+        self.heatmap_x_axis = options.layout[1][0][0]
+        self.heatmap_y_axis = options.layout[1][0][1]
+        self.heatmap_colormap = options.layout[1][0][2]
+        self.heatmap_background_color = options.layout[1][0][3]
+        self.heatmap_precursor_size = options.layout[1][0][4]
+        self.heatmap_precursor_color = options.layout[1][0][5]
         self.colorscale_qualitative = options.layout[2][0][0]
         self.colorscale_sequential = options.layout[2][0][1]
         self.layout_target_mode = None
@@ -1698,7 +1779,7 @@ class TargetModeTab(object):
                                     mz_tol=self.mz_tol.value,
                                     rt_tol=self.rt_tol.value,
                                     im_tol=self.im_tol.value,
-                                    title=f"Precursor/fragments elution profile of {peptide['name']}({peptide['sequence']}) in RT and RT/IM dimensions ({peptide['rt'] / 60: .2f} min)",
+                                    title=f"Precursor fragment elution profiles of {peptide['name']}({peptide['sequence']}) in RT and RT/IM dimensions ({peptide['rt'] / 60: .2f} min)",
                                     colorscale_qualitative=self.colorscale_qualitative.value,
                                     colorscale_sequential=self.colorscale_sequential.value,
                                     height=500,
@@ -1829,8 +1910,8 @@ class AlphaVizGUI(GUI):
 
         self.data = DataImportWidget()
         self.options = OptionsWidget(self.data)
-        self.options.add_option(HeatmapOptionsWidget().create_layout())
         self.options.add_option(ToleranceOptionsWidget().create_layout())
+        self.options.add_option(HeatmapOptionsWidget().create_layout())
         self.options.add_option(ColorscaleOptionsWidget().create_layout())
         self.tabs = TabsWidget(self.data, self.options)
         self.layout += [
