@@ -26,7 +26,8 @@ def plot_sequence_coverage(
     peptides_list: list,
     colorscale_qualitative: str,
     colorscale_sequential: str,
-    regex: str
+    regex: str,
+    prot_id: str = ""
 )-> go.Figure:
     """Create a protein sequence coverage plot.
 
@@ -52,8 +53,12 @@ def plot_sequence_coverage(
     """
     fig = go.Figure()
 
-    aa_position = list(range(1, len(sequence) + 1))
-    aa_list = list(sequence)
+    try:
+        aa_position = list(range(1, len(sequence) + 1))
+        aa_list = list(sequence)
+    except TypeError:
+        print(f"The AA sequence is not found in the fasta file for the selected protein_id {prot_id}.")
+        return None
 
     fig.add_trace(
         go.Bar(
@@ -73,16 +78,20 @@ def plot_sequence_coverage(
             start = sequence.find(peptide)
             peptide_cov = range(start + 1, start + len(peptide) + 1)
             selected_peptide_cov[start + 1: start + len(peptide) + 1] = True
-            fig.add_trace(
-                go.Bar(
-                    x=list(peptide_cov),
-                    y=np.ones(len(peptide))*2,
-                    name=f'Peptide: {peptide_mod}',
-                    hovertemplate='<br><b>position:</b> %{x}.',
-                    opacity=0.5,
-                    marker=dict(color=getattr(px.colors.qualitative, colorscale_qualitative)[ind])
+            if start != -1:
+                fig.add_trace(
+                    go.Bar(
+                        x=list(peptide_cov),
+                        y=np.ones(len(peptide))*2,
+                        name=f'Peptide: {peptide_mod}',
+                        hovertemplate='<br><b>position:</b> %{x}.',
+                        opacity=0.5,
+                        marker=dict(color=getattr(px.colors.qualitative, colorscale_qualitative)[ind])
+                    )
                 )
-            )
+            else:
+                print(f'The peptide {peptide} is not found in the protein sequence of the protein_id {prot_id}.')
+                return None
     else:
         colorscale_sequential_colors = px.colors.sample_colorscale(colorscale_sequential, samplepoints=len(peptides_list))
         for ind, peptide_mod in enumerate(peptides_list):
@@ -91,20 +100,24 @@ def plot_sequence_coverage(
             start = sequence.find(peptide)
             peptide_cov = range(start + 1, start + len(peptide) + 1)
             selected_peptide_cov[start + 1: start + len(peptide) + 1] = True
-            fig.add_trace(
-                go.Bar(
-                    x=list(peptide_cov),
-                    y=np.ones(len(peptide))*2,
-                    name=f'Peptide: {peptide_mod}',
-                    hovertemplate='<br><b>position:</b> %{x}.',
-                    opacity=0.5,
-                    marker=dict(color=colorscale_sequential_colors[ind])
+            if start != -1:
+                fig.add_trace(
+                    go.Bar(
+                        x=list(peptide_cov),
+                        y=np.ones(len(peptide))*2,
+                        name=f'Peptide: {peptide_mod}',
+                        hovertemplate='<br><b>position:</b> %{x}.',
+                        opacity=0.5,
+                        marker=dict(color=colorscale_sequential_colors[ind])
+                    )
                 )
-            )
+            else:
+                print(f'The peptide {peptide} is not found in the protein sequence of the protein_id {prot_id}.')
+                return None
     aa_coverage = round(np.sum(selected_peptide_cov) / len(selected_peptide_cov) * 100, 2)
     fig.update_layout(
         title=dict(
-            text=f"Protein coverage diagram ({gene_name})" + '\n' + f"(AA coverage {aa_coverage}%)",
+            text=f"Protein coverage diagram (protein ID {prot_id})" + '\n' + f"(AA coverage {aa_coverage}%)",
             font=dict(
                 size=16,
             ),
@@ -221,7 +234,7 @@ def plot_chrom(
 
 def plot_heatmap(
     df: pd.DataFrame,
-    x_axis_label: str = "RT, min",
+    x_axis_label: str = "m/z, Th",
     y_axis_label: str = "Inversed IM, V·s·cm\u207B\u00B2",
     z_axis_label: str = "Intensity",
     mz: float = 0.0,
@@ -279,7 +292,6 @@ def plot_heatmap(
 
     """
     labels = {
-        'RT, min': "rt_values",
         'm/z, Th': "mz_values",
         'Inversed IM, V·s·cm\u207B\u00B2': "mobility_values",
         'Intensity': "intensity_values",
@@ -325,12 +337,18 @@ def plot_heatmap(
     ).opts(plot=opts_ms1)
 
     if mz and im:
-        precursor = hv.Points((mz, im)).opts(
-            marker='x',
-            size=precursor_size,
-            color=precursor_color,
-            # axiswise=True,
-        )
+        if x_dimension == 'mz_values' and y_dimension == 'mobility_values':
+            precursor = hv.Points((mz, im)).opts(
+                marker='x',
+                size=precursor_size,
+                color=precursor_color,
+            )
+        else:
+            precursor = hv.Points((im, mz)).opts(
+                marker='x',
+                size=precursor_size,
+                color=precursor_color,
+            )
         return fig * precursor
     return fig
 
@@ -589,17 +607,18 @@ def plot_mass_spectra(
     )
 
     fig_common = plotly.subplots.make_subplots(
-        rows=5, cols=3, shared_xaxes=True,
+        rows=6, cols=3, shared_xaxes=True,
         figure=fig,
         specs=[
           [{"rowspan": 3, "colspan": 3}, None, None],
           [None, None, None],
           [None, None, None],
-          [{"colspan": 3}, None, None],
-          [{}, {}, {}]
+          [{"rowspan": 2, "colspan": 3}, None, None],
+          [None, None, None],
+          [{"colspan": 3}, None, None]
         ],
-        vertical_spacing=0.07,
-        column_widths=[0.25, 0.5, 0.25]
+        vertical_spacing=0.09,
+
     )
 
     # add a second plot
@@ -635,92 +654,92 @@ def plot_mass_spectra(
     )
 
     fig_common.update_yaxes(title_text="Error, ppm", row=4, col=1)
+    fig_common.update_xaxes(range=[data.mz_values.min()-10, data.mz_values.max()+10], row=4, col=1)
+    fig_common.update_xaxes(range=[data.mz_values.min()-10, data.mz_values.max()+10], row=1, col=1)
 
     bions = alphaviz.preprocessing.get_identified_ions(data.ions, sequence, 'b')
     yions = alphaviz.preprocessing.get_identified_ions(data.ions, sequence, 'y')
 
     sl = len(sequence)
-    distance = (data.mz_values.max() - data.mz_values.min()) / sl
-    correct_value = distance * 0.5
-    correct_value_2 = distance * 0.3
-    multipl_value = distance + correct_value
+    distance_from_side = (data.mz_values.max() - data.mz_values.min()) * 2/8
+    distance = np.linspace(data.mz_values.min()+distance_from_side, data.mz_values.max()-distance_from_side, sl)
     for i, aa in enumerate(sequence):
         fig_common.add_annotation(
             dict(
                 text=aa,
-                x=i*multipl_value,
+                x=distance[i],
                 y=0,
                 showarrow=False,
                 font_size=font_size_seq,
                 yshift=1, align='center'
             ),
-            row=5,
-            col=2
+            row=6,
+            col=1
         )
     for i, b in enumerate(bions):
         if b:
             fig_common.add_trace(
                 go.Scatter(
-                    x=[i*multipl_value,i*multipl_value+correct_value,i*multipl_value+correct_value],
-                    y=[0.8,0.8,0],
+                    x=[distance[i],distance[i] + (distance[i+1] - distance[i])/2,distance[i] + (distance[i+1] - distance[i])/2],
+                    y=[0.7,0.7,0],
                     mode="lines",
                     showlegend=False,
                     marker_color=b_ion_color,
                     line_width=spectrum_line_width,
                     hoverinfo='skip'
                 ),
-                row=5,
-                col=2
+                row=6,
+                col=1
             )
             fig_common.add_annotation(
                 dict(
                     text="b{}".format(str(i+1)),
-                    x=i*multipl_value+correct_value_2,
-                    y=1.4,
+                    x=distance[i] + (distance[i+1] - distance[i])/4,
+                    y=1.1,
                     showarrow=False,
                     font_size=font_size_ion
                 ),
-                row=5,
-                col=2
+                row=6,
+                col=1
             )
     for i, y in enumerate(yions):
         if y:
             fig_common.add_trace(
                 go.Scatter(
-                    x=[i*multipl_value,i*multipl_value-correct_value,i*multipl_value-correct_value],
-                    y=[-0.8,-0.8,0],
+                    x=[distance[i],distance[i] - (distance[i+1] - distance[i])/2,distance[i] - (distance[i+1] - distance[i])/2],
+                    y=[-0.7,-0.7,0],
                     mode="lines",
                     showlegend=False,
                     marker_color=y_ion_color,
                     line_width=spectrum_line_width,
                     hoverinfo='skip'
                 ),
-                row=5,
-                col=2
+                row=6,
+                col=1
             )
             fig_common.add_annotation(
                 dict(
                     text="y{}".format(str(sl-i)),
-                    x=i*multipl_value-correct_value_2,
-                    y=-1.4,
+                    x=distance[i] - (distance[i+1] - distance[i])/4,
+                    y=-1.1,
                     showarrow=False,
                     font_size=font_size_ion
                 ),
-                row=5,
-                col=2
+                row=6,
+                col=1
             )
     fig_common.update_yaxes(
         visible=False,
-        range=(-1.5,1.5),
-        row=5,
-        col=2
+        range=(-1.1,1.1),
+        row=6,
+        col=1
     )
     fig_common.update_xaxes(
         visible=False,
-        row=5,
-        col=2
+        row=6,
+        col=1
     )
-
+    fig_common.update_xaxes(matches='x')
     return fig_common # this function is quite long. Can it be split in smaller chunks?
 
 
@@ -728,7 +747,8 @@ def plot_mass_error(
     df: pd.DataFrame,
     x_axis_label: str,
     y_axis_label: str,
-    plot_title: str
+    plot_title: str,
+    mz_tol: float = None
 )-> go.Figure:
     """Create a density plot superimposed on the scatter plot together with the 1D distributions of both variables as marginal histograms.
 
@@ -800,6 +820,35 @@ def plot_mass_error(
             )
         )
     )
+    if mz_tol:
+        fig.add_trace(
+            go.Scatter(
+                x = [df[x_axis_label].values.min(), df[x_axis_label].values.max()],
+                y = [mz_tol, mz_tol],
+                mode='lines',
+                line=dict(
+                    color='darkred',
+                    width=2,
+                    dash='dash'
+                ),
+                showlegend = False,
+                hoverinfo='none',
+            )
+        )
+        fig.add_trace(
+            go.Scatter(
+                x = [df[x_axis_label].values.min(), df[x_axis_label].values.max()],
+                y = [-mz_tol, -mz_tol],
+                mode='lines',
+                line=dict(
+                    color='darkred',
+                    width=2,
+                    dash='dash'
+                ),
+                showlegend = False,
+                hoverinfo='none',
+            )
+        )
 
     fig.update_layout(
         autosize = False,
@@ -983,6 +1032,7 @@ def plot_elution_heatmap(
         bgcolor=background_color,
         framewise=True,
         axiswise=True,
+        fontsize={'title': 12},
         **kwargs
     )
     dmap = hv.DynamicMap(
@@ -1079,7 +1129,7 @@ def plot_elution_profile_heatmap(
 
     common_plot = plot_elution_heatmap(
         timstof_data.as_dataframe(precursor_indices),
-        title='precursor',
+        title="precursor",
         # width=width,
         height=height,
         background_color=background_color,
@@ -1102,7 +1152,7 @@ def plot_elution_profile_heatmap(
         if len(fragment_data_indices) > 0:
             common_plot += plot_elution_heatmap(
                 timstof_data.as_dataframe(fragment_data_indices),
-                title=frag,
+                title=f"{frag} ({round(frag_mz, 3)})",
                 # width=width,
                 height=height,
                 background_color=background_color,
@@ -1260,6 +1310,7 @@ def plot_elution_profile(
             raw_data,
             precursor_indices,
             remove_zeros=True,
+            # label=f"precursor ({round(peptide_info['mz'], 3)})",
             label='precursor',
             marker_color=dict(color=colors_set[0])
         )
@@ -1279,7 +1330,7 @@ def plot_elution_profile(
                     raw_data,
                     fragment_data_indices,
                     remove_zeros=True,
-                    label=frag,
+                    label=f"{frag} ({round(frag_mz, 3)})",
                     marker_color=dict(color=colors_set[ind+1])
                 )
             )
